Struct tendermint_machine::ext::BlockNumber
source · pub struct BlockNumber(pub u64);Expand description
A struct containing a Block Number, wrapped to have a distinct type.
Tuple Fields
0: u64Trait Implementations
sourceimpl Clone for BlockNumber
impl Clone for BlockNumber
sourcefn clone(&self) -> BlockNumber
fn clone(&self) -> BlockNumber
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for BlockNumber
impl Debug for BlockNumber
sourceimpl Decode for BlockNumber
impl Decode for BlockNumber
sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy
) -> Result<Self, Error>
Attempt to deserialise the value from input.
sourcefn skip<I>(input: &mut I) -> Result<(), Error>where
I: Input,
fn skip<I>(input: &mut I) -> Result<(), Error>where
I: Input,
Attempt to skip the encoded value from input. Read more
sourcefn encoded_fixed_size() -> Option<usize>
fn encoded_fixed_size() -> Option<usize>
Returns the fixed encoded size of the type. Read more
sourceimpl Encode for BlockNumber
impl Encode for BlockNumber
sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy
)
Convert self to a slice and append it to the destination.
sourcefn using_encoded<R, F: FnOnce(&[u8]) -> R>(&self, f: F) -> R
fn using_encoded<R, F: FnOnce(&[u8]) -> R>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
sourceimpl Hash for BlockNumber
impl Hash for BlockNumber
sourceimpl PartialEq<BlockNumber> for BlockNumber
impl PartialEq<BlockNumber> for BlockNumber
sourcefn eq(&self, other: &BlockNumber) -> bool
fn eq(&self, other: &BlockNumber) -> bool
impl Copy for BlockNumber
impl EncodeLike<BlockNumber> for BlockNumber
impl Eq for BlockNumber
impl StructuralEq for BlockNumber
impl StructuralPartialEq for BlockNumber