Struct tendermint_machine::ext::Commit
source · pub struct Commit<S: SignatureScheme> {
pub end_time: u64,
pub validators: Vec<S::ValidatorId>,
pub signature: S::AggregateSignature,
}Expand description
A commit for a specific block. The list of validators have weight exceeding the threshold for a valid commit.
Fields
end_time: u64End time of the round, used as the start time of next round.
validators: Vec<S::ValidatorId>Validators participating in the signature.
signature: S::AggregateSignatureAggregate signature.