Signature

Trait Signature 

pub trait Signature:
    Send
    + Sync
    + Clone
    + PartialEq
    + Debug
    + Encode
    + Decode { }
An alias for a series of traits required for a type to be usable as a signature, automatically implemented for all types satisfying those traits.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors