ValidatorId

Trait ValidatorId 

pub trait ValidatorId:
    Send
    + Sync
    + Clone
    + Copy
    + PartialEq
    + Eq
    + Hash
    + Debug
    + Encode
    + Decode { }
An alias for a series of traits required for a type to be usable as a validator ID, automatically implemented for all types satisfying those traits.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors