pub struct Commit<A: AggregateSignature> { /* private fields */ }Expand description
A commit for a specific block.
In order for this to be valid, the signature MUST be valid and aggregated from signatures by validators whose weight is sufficient for the threshold. Deserialization or instantiation alone DOES NOT signify validity.
Implementations
Sourceimpl<A: AggregateSignature> Commit<A>
impl<A: AggregateSignature> Commit<A>
Sourcepub fn block_number(&self) -> BlockNumber
pub fn block_number(&self) -> BlockNumber
The block number this commit is for.