SignedMessage

Struct SignedMessage 

pub struct SignedMessage<V: ValidatorId, B: Block, S: Signature> { /* private fields */ }
A signed Tendermint consensus message to be broadcast to the other validators.

Implementations

Source

impl<V: ValidatorId, B: Block, S: Signature> SignedMessage<V, B, S>

pub fn block(&self) -> BlockNumber

Number of the block this message is attempting to add to the chain.

pub fn verify_signature<Scheme: SignatureScheme<ValidatorId = V, Signature = S>>( &self, signer: &Scheme, ) -> bool