AggregateSignature

Trait AggregateSignature 

pub trait AggregateSignature: Clone + AsRef<[u8]> { }
A representation of an aggregate signature.

This is effectively a trait alias where a potential representation of an aggregate signature is any type which satisfies all of these bounds, and this is implemented for all such types.

The [BorshSerialize] implementation MUST be infallible if the underlying writer is infallible. The [BorshDeserialize] implementation MUST be infallible if it is deserializing a value which was successfully serialized, from a well-formed reader.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors