Signature

Trait Signature 

pub trait Signature: Clone + AsRef<[u8]> { }
A representation of a signature.

This is effectively a trait alias where a potential representation of a signature is any type which satisfies all of these bounds, and this is implemented for all such types.

The AsRef<[u8]> implementation MUST return a slice with a consistent length for any value, meaning it’s constant.

The [BorshSerialize] implementation MUST be infallible if the underlying writer is infallible. The [BorshDeserialize] implementation MUST be infallible if it is deserializing a value which was successfully serialized, from a well-formed reader.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<S: Clone + AsRef<[u8]>> Signature for S