Crate tendermint_machine

Crate tendermint_machine 

Modules

ext
Traits and types of the external network being integrated with to provide consensus over.

Structs

SignedMessage
A signed Tendermint consensus message to be broadcast to the other validators.
TendermintHandle
A Tendermint machine and its channel to receive messages from the gossip layer over.
TendermintMachine
A machine executing the Tendermint protocol.

Type Aliases

MessageSender
SignedMessageFor
Type alias to the SignedMessage type for a given Network
StepSender