Skip to main contentCrate tendermint_machine
Source - ext
- Traits and types of the external network being integrated with to provide consensus over.
- SignedMessage
- A signed Tendermint consensus message to be broadcast to the other validators.
- TendermintHandle
- A Tendermint machine and its channel to receive messages from the gossip layer over.
- TendermintMachine
- A machine executing the Tendermint protocol.
- MessageSender
- SignedMessageFor
- Type alias to the SignedMessage type for a given Network
- StepSender