Traits and types of the external network being integrated with to provide consensus over.
Structs
- Block
Number - A struct containing a Block Number, wrapped to have a distinct type.
- Commit
- A commit for a specific block. The list of validators have weight exceeding the threshold for a valid commit.
- Round
Number - A struct containing a round number, wrapped to have a distinct type.
Enums
- Block
Error - Simplified error enum representing a block’s validity.
Traits
- Block
- Trait representing a Block.
- Network
- Trait representing the distributed system Tendermint is providing consensus over.
- Signature
- An alias for a series of traits required for a type to be usable as a signature, automatically implemented for all types satisfying those traits.
- Signature
Scheme - A signature scheme used by validators.
- Signer
- A signer for a validator.
- Validator
Id - An alias for a series of traits required for a type to be usable as a validator ID, automatically implemented for all types satisfying those traits.
- Weights
- Weights for the validators present.