Module tendermint_machine::ext

source ·
Traits and types of the external network being integrated with to provide consensus over.

Structs

A struct containing a Block Number, wrapped to have a distinct type.
A commit for a specific block. The list of validators have weight exceeding the threshold for a valid commit.
A struct containing a round number, wrapped to have a distinct type.

Enums

Simplified error enum representing a block’s validity.

Traits

Trait representing a Block.
Trait representing the distributed system Tendermint is providing consensus over.
An alias for a series of traits required for a type to be usable as a signature, automatically implemented for all types satisfying those traits.
A signature scheme used by validators.
A signer for a validator.
An alias for a series of traits required for a type to be usable as a validator ID, automatically implemented for all types satisfying those traits.
Weights for the validators present.