Enum tendermint_machine::ext::BlockError
source · pub enum BlockError {
Fatal,
Temporal,
}Expand description
Simplified error enum representing a block’s validity.
Variants
Fatal
Malformed block which is wholly invalid.
Temporal
Valid block by syntax, with semantics which may or may not be valid yet are locally considered invalid. If a block fails to validate with this, a slash will not be triggered.