pub trait Signature: Send + Sync + Clone + PartialEq + Debug + Encode + Decode { }
An alias for a series of traits required for a type to be usable as a signature, automatically implemented for all types satisfying those traits.

Implementors