Trait tendermint_machine::ext::Signature
source · Expand description
An alias for a series of traits required for a type to be usable as a signature, automatically implemented for all types satisfying those traits.
An alias for a series of traits required for a type to be usable as a signature, automatically implemented for all types satisfying those traits.