pub trait ValidatorId: Send + Sync + Clone + Copy + PartialEq + Eq + Hash + Debug + Encode + Decode { }
An alias for a series of traits required for a type to be usable as a validator ID, automatically implemented for all types satisfying those traits.

Implementors