pub struct BlockNumber(/* private fields */);Expand description
A block’s number.
The genesis block is considered to have number 0 where following blocks’ numbers increase
incrementally by one.
As this library never works with the genesis block, as it’s constant and does not undergo the
consensus process, this library represents block numbers via NonZero. This is complete to
all block numbers this library has to consider.