Commit

Struct Commit 

pub struct Commit<A: AggregateSignature> { /* private fields */ }
A commit for a specific block.

In order for this to be valid, the signature MUST be valid and aggregated from signatures by validators whose weight is sufficient for the threshold. Deserialization or instantiation alone DOES NOT signify validity.

Implementations

Source

impl<A: AggregateSignature> Commit<A>

pub fn block_number(&self) -> BlockNumber

The block number this commit is for.

pub fn verify<S: ?Sized + SignatureScheme<AggregateSignature = A>>( &self, validator_set: &(impl ?Sized + ValidatorSet<Validator = S::Validator>), signature_scheme: &S, genesis: impl AsRef<[u8]>, block_hash: impl AsRef<[u8]>, ) -> bool

Verify a commit.