ProcessTerminated

Struct ProcessTerminated 

pub struct ProcessTerminated;
Available on crate feature std only.
The Tendermint process was terminated.

This occurs when the future terminates, either due to being itself dropped or due to its handle being dropped.