Struct tendermint_machine::SignedMessage
source · pub struct SignedMessage<V: ValidatorId, B: Block, S: Signature> { /* private fields */ }Expand description
A signed Tendermint consensus message to be broadcast to the other validators.
Implementations
sourceimpl<V: ValidatorId, B: Block, S: Signature> SignedMessage<V, B, S>
impl<V: ValidatorId, B: Block, S: Signature> SignedMessage<V, B, S>
sourcepub fn number(&self) -> BlockNumber
pub fn number(&self) -> BlockNumber
Number of the block this message is attempting to add to the chain.
pub fn verify_signature<Scheme: SignatureScheme<ValidatorId = V, Signature = S>>(
&self,
signer: &Scheme
) -> bool