pub struct TendermintHandle<N: Network> {
pub step: StepSender<N>,
pub messages: MessageSender<N>,
pub machine: TendermintMachine<N>,
}Expand description
A Tendermint machine and its channel to receive messages from the gossip layer over.
Fields
step: StepSender<N>Channel to trigger the machine to move to the next block. Takes in the the previous block’s commit, along with the new proposal.
messages: MessageSender<N>Channel to send messages received from the P2P layer.
machine: TendermintMachine<N>Tendermint machine to be run on an asynchronous task.