Struct tendermint_machine::TendermintHandle
source · pub struct TendermintHandle<N: Network> {
pub messages: Sender<SignedMessage<N::ValidatorId, N::Block, <N::SignatureScheme as SignatureScheme>::Signature>>,
pub handle: JoinHandle<()>,
}Expand description
A handle to an asynchronous task, along with a channel to inform of it of messages received.
Fields
messages: Sender<SignedMessage<N::ValidatorId, N::Block, <N::SignatureScheme as SignatureScheme>::Signature>>Channel to send messages received from the P2P layer.
handle: JoinHandle<()>Handle for the asynchronous task executing the machine. The task will automatically exit when the channel is dropped.