pub struct TendermintMachine<N: Network> { /* private fields */ }Expand description
A machine executing the Tendermint protocol.
Implementations
Sourceimpl<N: Network + 'static> TendermintMachine<N>
impl<N: Network + 'static> TendermintMachine<N>
Sourcepub async fn new(
network: N,
last_block: BlockNumber,
last_time: u64,
proposal: N::Block,
) -> TendermintHandle<N>
pub async fn new( network: N, last_block: BlockNumber, last_time: u64, proposal: N::Block, ) -> TendermintHandle<N>
Create a new Tendermint machine, from the specified point, with the specified block as the
one to propose next. This will return a channel to send messages from the gossip layer and
the machine itself. The machine should have run called from an asynchronous task.
pub async fn run(self)