pub struct TendermintMachine<N: Network> { /* private fields */ }
A machine executing the Tendermint protocol.

Implementations

Create a new Tendermint machine, for the specified proposer, from the specified block, with the specified block as the one to propose next, returning a handle for the machine.