Struct tendermint_machine::TendermintMachine
source · pub struct TendermintMachine<N: Network> { /* private fields */ }Expand description
A machine executing the Tendermint protocol.
Implementations
sourceimpl<N: Network + 'static> TendermintMachine<N>
impl<N: Network + 'static> TendermintMachine<N>
sourcepub fn new(
network: N,
last: (BlockNumber, u64),
proposal: N::Block
) -> TendermintHandle<N>
pub fn new(
network: N,
last: (BlockNumber, u64),
proposal: N::Block
) -> TendermintHandle<N>
Create a new Tendermint machine, for the specified proposer, from the specified block, with the specified block as the one to propose next, returning a handle for the machine.